EqualityMap<K, V> class

A Map whose key equality is determined by an Equality object.

Inheritance
Available extensions

Constructors

EqualityMap(Equality<K> equality)
Creates a map with equality based on equality.
EqualityMap.from(Equality<K> equality, Map<K, V> other)
Creates a map with equality based on equality that contains all key-value pairs of other.

Properties

entries Iterable<MapEntry<K, V>>
The map entries of this Map.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
Whether there is no key/value pair in the map.
no setterinherited
isNotEmpty bool
Whether there is at least one key/value pair in the map.
no setterinherited
keys Iterable<K>
The keys of this Map.
no setterinherited
length int
The number of key/value pairs in the map.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Iterable<V>
The values of this Map.
no setterinherited

Methods

addAll(Map<K, V> other) → void
Adds all key/value pairs of other to this map.
inherited
addEntries(Iterable<MapEntry<K, V>> entries) → void
Adds all key/value pairs of newEntries to this map.
inherited
cast<K2, V2>() Map<K2, V2>
Provides a view of this map as having RK keys and RV instances, if necessary.
inherited
clear() → void
Removes all entries from the map.
inherited
containsKey(Object? key) bool
Whether this map contains the given key.
inherited
containsValue(Object? value) bool
Whether this map contains the given value.
inherited
differentKeys(Map<K, V> other) Set<K>

Available on Map<K, V>, provided by the JunnyMapExtension extension

返回当前 Map 与另一个 Map other 中值不同的键集合。
forEach(void f(K, V)) → void
Applies action to each key/value pair of the map.
inherited
map<K2, V2>(MapEntry<K2, V2> transform(K, V)) Map<K2, V2>
Returns a new map where all entries of this map are transformed by the given convert function.
inherited
moveKeyToLast(K key) Map<K, V>

Available on Map<K, V>, provided by the JunnyMapExtension extension

将指定的键 key 移动到 Map 的末尾。
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
otherDifference(Map<K, V> other) Map<K, V>

Available on Map<K, V>, provided by the JunnyMapExtension extension

返回一个新 Map,包含 other 中与当前 Map 比较后值不同的键值对。
parse<T>([dynamic key0, dynamic key1, dynamic key2, dynamic key3, dynamic key4, dynamic key5, dynamic key6, dynamic key7, dynamic key8, dynamic key9]) → T

Available on Map<K, V>, provided by the JsonParseExtension extension

解析基础数据类型 T
parseList<T>([dynamic key0, dynamic key1, dynamic key2, dynamic key3, dynamic key4, dynamic key5, dynamic key6, dynamic key7, dynamic key8, dynamic key9]) List<T>

Available on Map<K, V>, provided by the JsonParseExtension extension

解析列表类型数据 List<T>
putIfAbsent(K key, V ifAbsent()) → V
Look up the value of key, or add a new entry if it isn't there.
inherited
remove(Object? key) → V?
Removes key and its associated value, if present, from the map.
inherited
removeKeys([Iterable<K>? keys]) Map<K, V>

Available on Map<K, V>, provided by the JunnyMapExtension extension

返回一个新 Map,去除指定的一组键 keys
removeWhere(bool test(K, V)) → void
Removes all entries of this map that satisfy the given test.
inherited
replaceKey(K fromKey, [K? toKey]) Map<K, V>

Available on Map<K, V>, provided by the JunnyMapExtension extension

替换 Map 中的键 fromKeytoKey
retainKeys([Iterable<K>? keys]) Map<K, V>

Available on Map<K, V>, provided by the JunnyMapExtension extension

返回一个新 Map,仅保留指定的一组键 keys
retype<K2, V2>() Map<K2, V2>
inherited
thisDifference(Map<K, V> other) Map<K, V>

Available on Map<K, V>, provided by the JunnyMapExtension extension

返回一个新 Map,包含当前 Map 中与 other 比较后值不同的键值对。
toString() String
A string representation of this object.
inherited
update(K key, V update(V), {V ifAbsent()?}) → V
Updates the value for the provided key.
inherited
updateAll(V update(K, V)) → void
Updates all values.
inherited
withoutKey(K key) Map<K, V>

Available on Map<K, V>, provided by the JunnyMapExtension extension

返回一个新 Map,去除指定的键 key

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Object? key) → V?
The value for the given key, or null if key is not in the map.
inherited
operator []=(K key, V value) → void
Associates the key with the given value.
inherited