JunnyLogLevel enum

日志级别枚举

Inheritance
Available extensions

Values

all → const JunnyLogLevel

开启所有日志

const JunnyLogLevel(0)
finest → const JunnyLogLevel

高度详细的日志

const JunnyLogLevel(300)
finer → const JunnyLogLevel

较详细的日志

const JunnyLogLevel(400)
fine → const JunnyLogLevel

信息日志

const JunnyLogLevel(500)
config → const JunnyLogLevel

配置日志

const JunnyLogLevel(700)
info → const JunnyLogLevel

信息日志

const JunnyLogLevel(800)
trace → const JunnyLogLevel

跟踪日志

const JunnyLogLevel(850)
warning → const JunnyLogLevel

警告日志

const JunnyLogLevel(900)
handle → const JunnyLogLevel

异常处理日志

const JunnyLogLevel(950)
severe → const JunnyLogLevel

严重错误日志

const JunnyLogLevel(1000)
shout → const JunnyLogLevel

高优先级日志

const JunnyLogLevel(1200)
off → const JunnyLogLevel

关闭所有日志

const JunnyLogLevel(2000)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
level int
日志级别
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<JunnyLogLevel>
A constant List of the values in this enum, in order of their declaration.